@@ -73,7 +73,7 @@
 #'     \item \code{arc = 'color:blue;'} for a blue text color each 2nd row.
 #'     \item \code{caption = '+color:red;'} to add red font-color to the default table caption style.
 #'   }
-#'   See further examples in \href{../doc/table_css.html}{this package-vignette}.
+#'   See further examples in \href{https://strengejacke.github.io/sjPlot/articles/table_css.html}{this package-vignette}.
 #'
 #' @examples
 #' \dontrun{
@@ -313,6 +313,7 @@ tab_model_df <- function(x,
     sort.column = NULL,
     include.table.tag = FALSE,
     no.last.table.row = TRUE,
+    zeroinf = is.zeroinf,
     ...
   )
 
@@ -389,7 +390,7 @@ tab_model_df <- function(x,
     )
 
     page.content <- paste0(page.content, "  <tr>\n")
-    page.content <- paste0(page.content, sprintf("    <td colspan=\"%i\" class=\"simplexparts\">Simplex Parameters</td>\n", ncol(x)))
+    page.content <- paste0(page.content, sprintf("    <td colspan=\"%i\" class=\"simplexparts\">Monotonic Effects</td>\n", ncol(x)))
     page.content <- paste0(page.content, "  </tr>\n")
 
     page.content <- paste0(page.content, sp.content)
@@ -426,6 +427,7 @@ tab_model_df <- function(x,
       sort.column = NULL,
       include.table.tag = FALSE,
       no.last.table.row = TRUE,
+      zeroinf = FALSE,
       ...
     )
 
