@@ -16,9 +16,9 @@
 #'     only contains one predictor, slope-line is plotted.}
 #'     \item{\code{type = "re"}}{For mixed effects models, plots the random
 #'     effects.}
-#'     \item{\code{type = "std"}}{Forest-plot of standardized beta values.}
-#'     \item{\code{type = "std2"}}{Forest-plot of standardized beta values,
-#'     however, standardization is done by dividing by two sd (see 'Details').}
+#'     \item{\code{type = "std"}}{Forest-plot of standardized coefficients.}
+#'     \item{\code{type = "std2"}}{Forest-plot of standardized coefficients,
+#'     however, standardization is done by dividing by two SD (see 'Details').}
 #'   }
 #'   \emph{Marginal Effects}  (\href{https://strengejacke.github.io/sjPlot/articles/plot_marginal_effects.html}{related vignette})
 #'   \describe{
@@ -146,7 +146,7 @@
 #'   \code{\link[lme4]{ranef}}) will be plotted. Default is \code{NULL}, so all
 #'   random effects will be plotted.
 #' @param title Character vector, used as plot title. By default,
-#'   \code{\link[sjlabelled]{get_dv_labels}} is called to retrieve the label of
+#'   \code{\link[sjlabelled]{response_labels}} is called to retrieve the label of
 #'   the dependent variable, which will be used as title. Use \code{title = ""}
 #'   to remove title.
 #' @param axis.title Character vector of length one or two (depending on the
@@ -157,7 +157,7 @@
 #'   \code{\link[ggplot2]{labs}}. Use \code{axis.title = ""} to remove axis
 #'   titles.
 #' @param axis.labels Character vector with labels for the model terms, used as
-#'   axis labels. By default, \code{\link[sjlabelled]{get_term_labels}} is
+#'   axis labels. By default, \code{\link[sjlabelled]{term_labels}} is
 #'   called to retrieve the labels of the coefficients, which will be used as
 #'   axis labels. Use \code{axis.labels = ""} or \code{auto.label = FALSE} to
 #'   use the variable names as labels instead. If \code{axis.labels} is a named
@@ -188,10 +188,11 @@
 #' @param se Logical, if \code{TRUE}, the standard errors are
 #'   also printed. If robust standard errors are required, use arguments
 #'   \code{vcov.fun}, \code{vcov.type} and \code{vcov.args} (see
-#'   \code{\link[sjstats]{robust}} for details). \code{se} overrides
-#'   \code{ci.lvl}: if not \code{NULL}, arguments \code{ci.lvl}
-#'   and \code{transform} will be ignored. Currently, \code{se} only applies
-#'   to \emph{Coefficients} plots.
+#'   \code{\link[parameters]{standard_error_robust}} and
+#'   \href{https://easystats.github.io/parameters/articles/model_parameters_robust.html}{this vignette}
+#'   for details), or use argument \code{robust} as shortcut. \code{se} overrides
+#'   \code{ci.lvl}: if not \code{NULL}, arguments \code{ci.lvl} and \code{transform}
+#'   will be ignored. Currently, \code{se} only applies to \emph{Coefficients} plots.
 #' @param show.intercept Logical, if \code{TRUE}, the intercept of the fitted
 #'   model is also plotted. Default is \code{FALSE}. If \code{transform =
 #'   "exp"}, please note that due to exponential transformation of estimates,
@@ -205,6 +206,12 @@
 #'   legend.
 #' @param show.zeroinf Logical, if \code{TRUE}, shows the zero-inflation part of
 #'   hurdle- or zero-inflated models.
+#' @param robust Logical, shortcut for arguments \code{vcov.fun} and \code{vcov.type}.
+#'   If \code{TRUE}, uses \code{vcov.fun = "vcovHC"} and \code{vcov.type = "HC3"} as
+#'   default, that is, \code{\link[sandwich]{vcovHC}} with default-type is called
+#'   (see \code{\link[parameters]{standard_error_robust}} and
+#'   \href{https://easystats.github.io/parameters/articles/model_parameters_robust.html}{this vignette}
+#'   for further details).
 #' @param vcov.fun Character vector, indicating the name of the \code{vcov*()}-function
 #'    from the \pkg{sandwich}-package, e.g. \code{vcov.fun = "vcovCL"}, if robust
 #'    standard errors are required.
@@ -247,14 +254,14 @@
 #'   default when prefixing labels.
 #' @param auto.label Logical, if \code{TRUE} (the default),
 #'    and \href{https://strengejacke.github.io/sjlabelled/articles/intro_sjlabelled.html}{data is labelled},
-#'    \code{\link[sjlabelled]{get_term_labels}} is called to retrieve the labels
+#'    \code{\link[sjlabelled]{term_labels}} is called to retrieve the labels
 #'    of the coefficients, which will be used as predictor labels. If data is
 #'    not labelled, \href{https://easystats.github.io/parameters/reference/format_parameters.html}{format_parameters()}
 #'    is used to create pretty labels. If \code{auto.label = FALSE},
 #'   original variable names and value labels (factor levels) are used.
 #' @param prefix.labels Indicates whether the value labels of categorical variables
 #'   should be prefixed, e.g. with the variable name or variable label. See
-#'   argument \code{prefix} in \code{\link[sjlabelled]{get_term_labels}} for
+#'   argument \code{prefix} in \code{\link[sjlabelled]{term_labels}} for
 #'   details.
 #' @param jitter Numeric, between 0 and 1. If \code{show.data = TRUE}, you can
 #'   add a small amount of random variation to the location of each data point.
@@ -331,23 +338,21 @@
 #'   (depending on the plot-type) a list of such data frames.
 #'
 #' @details
-#'   \code{get_model_data()} simply calls \code{plot_model()} and returns
-#'   the data from the ggplot-object. Hence, it is rather inefficient and should
-#'   be used as alternative to \pkg{brooms} \code{tidy()}-function only in
-#'   specific situations. \cr \cr Some details on the different plot-types:
+#' \subsection{Different Plot Types}{
 #'   \describe{
-#'   \item{\code{type = "std2"}}{Plots standardized beta values,
-#'     however, standardization follows Gelman's (2008) suggestion, rescaling the
+#'   \item{\code{type = "std"}}{Plots standardized estimates. See details below.}
+#'   \item{\code{type = "std2"}}{Plots standardized estimates, however,
+#'     standardization follows Gelman's (2008) suggestion, rescaling the
 #'     estimates by dividing them by two standard deviations instead of just one.
 #'     Resulting coefficients are then directly comparable for untransformed
 #'     binary predictors.
 #'   }
-#'   \item{\code{type = "pred"}}{Plots marginal effects. Simply wraps
-#'     \code{\link[ggeffects]{ggpredict}}. See also
+#'   \item{\code{type = "pred"}}{Plots estimated marginal means (or marginal effects).
+#'     Simply wraps \code{\link[ggeffects]{ggpredict}}. See also
 #'     \href{https://strengejacke.github.io/sjPlot/articles/plot_marginal_effects.html}{this package-vignette}.
 #'   }
-#'   \item{\code{type = "eff"}}{Plots marginal effects. Simply wraps
-#'     \code{\link[ggeffects]{ggeffect}}. See also
+#'   \item{\code{type = "eff"}}{Plots estimated marginal means (or marginal effects).
+#'     Simply wraps \code{\link[ggeffects]{ggeffect}}. See also
 #'     \href{https://strengejacke.github.io/sjPlot/articles/plot_marginal_effects.html}{this package-vignette}.
 #'   }
 #'   \item{\code{type = "int"}}{A shortcut for marginal effects plots, where
@@ -378,9 +383,21 @@
 #'   multicollinearity-check (Variance Inflation Factors), QQ-plots,
 #'   checks for normal distribution of residuals and homoscedasticity
 #'   (constant variance of residuals) are shown. For \strong{generalized
-#'   lineare mixed models}, returns the QQ-plot for random effects.
+#'   linear mixed models}, returns the QQ-plot for random effects.
 #'   }
 #'   }
+#' }
+#' \subsection{Standardized Estimates}{
+#'   Default standardization is done by completely refitting the model on the
+#'   standardized data. Hence, this approach is equal to standardizing the
+#'   variables before fitting the model, which is particularly recommended for
+#'   complex models that include interactions or transformations (e.g., polynomial
+#'   or spline terms). When \code{type = "std2"}, standardization of estimates
+#'   follows \href{http://www.stat.columbia.edu/~gelman/research/published/standardizing7.pdf}{Gelman's (2008)}
+#'   suggestion, rescaling the estimates by dividing them by two standard deviations
+#'   instead of just one. Resulting coefficients are then directly comparable for
+#'   untransformed binary predictors.
+#' }
 #'
 #' @references
 #'   Gelman A (2008) "Scaling regression inputs by dividing by two
@@ -413,13 +430,13 @@
 #' plot_grid(p)}
 #'
 #' # plot random effects
-#' library(lme4)
-#' m <- lmer(Reaction ~ Days + (Days | Subject), sleepstudy)
-#' plot_model(m, type = "re")
-#'
-#' # plot marginal effects
-#' plot_model(m, type = "pred", terms = "Days")
+#' if (require("lme4")) {
+#'   m <- lmer(Reaction ~ Days + (Days | Subject), sleepstudy)
+#'   plot_model(m, type = "re")
 #'
+#'   # plot marginal effects
+#'   plot_model(m, type = "pred", terms = "Days")
+#' }
 #' # plot interactions
 #' \dontrun{
 #' m <- glm(
@@ -448,7 +465,7 @@
 #'
 #' @importFrom insight model_info find_predictors
 #' @importFrom sjmisc word_wrap str_contains
-#' @importFrom sjlabelled get_dv_labels get_term_labels
+#' @importFrom sjlabelled response_labels term_labels
 #' @importFrom dplyr if_else n_distinct
 #' @importFrom graphics plot
 #' @importFrom ggeffects ggpredict ggeffect
@@ -476,6 +493,7 @@ plot_model <- function(model,
                        grid.breaks = NULL,
                        ci.lvl = NULL,
                        se = NULL,
+                       robust = FALSE,
                        vcov.fun = NULL,
                        vcov.type = c("HC3", "const", "HC", "HC0", "HC1", "HC2", "HC4", "HC4m", "HC5"),
                        vcov.args = NULL,
@@ -521,6 +539,11 @@ plot_model <- function(model,
       case <- NULL
   }
 
+  if (isTRUE(robust)) {
+    vcov.type <- "HC3"
+    vcov.fun <- "vcovHC"
+  }
+
   # check se-argument
   vcov.fun <- check_se_argument(se = vcov.fun, type = type)
 
@@ -549,12 +572,12 @@ plot_model <- function(model,
   if (type %in% c("est", "std", "std2") && isTRUE(auto.label)) {
 
     # get labels of dependent variables, and wrap them if too long
-    if (is.null(title)) title <- sjlabelled::get_dv_labels(model, case = case, mv = fam.info$is_multivariate, ...)
+    if (is.null(title)) title <- sjlabelled::response_labels(model, case = case, mv = fam.info$is_multivariate, ...)
     title <- sjmisc::word_wrap(title, wrap = wrap.title)
 
     # labels for axis with term names
     if (is.null(axis.labels)) {
-      term_labels <- sjlabelled::get_term_labels(model, case = case, prefix = prefix.labels, ...)
+      term_labels <- sjlabelled::term_labels(model, case = case, prefix = prefix.labels, ...)
       if (.labelled_model_data(model) || is.stan(model)) axis.labels <- term_labels
     }
     axis.labels <- sjmisc::word_wrap(axis.labels, wrap = wrap.labels)
